/*
** Module   : PlatformHelper.java
** Abstract : provides a set of useful OS dependent helper methods
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 EVL 20130108          Initial version with static method to detect
**                           if the current OS belongs to the Windows family.
*/

package com.goldencode.util;

/**
 * Provides a set of methods to help in processing with different operating
 * systems.
 * <p>
 * Most (if not all) of these methods are stateless and thus are implemented
 * as static methods. 
 * 
 * @author EVL
 * @version 1.0.0
 */
public class PlatformHelper
{
   /** Variable to indicate if we need to detect current Windows family. */
   private static boolean winFamilyDetect = true;

   /** Variable to cache the current OS Windows family value. */
   private static boolean winFamily = false;
   
   /**
    * Checks is the current OS the P2J is running on belongs to the Windows
    * family.
    *
    * @return   <code>true</code> if the current OS is from Windows family or 
    *           <code>false</code> otherwise.
    */
   public static boolean isUnderWindowsFamily()
   {
      if (winFamilyDetect)
      {
         // Call this code only once 
         winFamilyDetect = false;
         winFamily =
               System.getProperty("os.name").toLowerCase().indexOf("win") >= 0;
      }
      
      return winFamily;
   }
}
